@@ -19,6 +19,10 @@
 #include "jsonrpc.h"
 #include <netinet/in.h>
 #include <netinet/tcp.h>
+#if HAVE_BLUEZ
+#include <bluetooth/bluetooth.h>
+#include <bluetooth/rfcomm.h>
+#endif
 
 #include "jsonrpc_methods.cc"
 
@@ -195,10 +199,13 @@ private:
     static void create_small_rackknob_(const char *id, const char *label);
     static void create_small_rackknobr_(const char *id, const char *label);
     static void create_master_slider_(const char *id, const char *label);
+    static void create_h_slider_(const char *id, const char *label);
     static void create_selector_no_caption_(const char *id);
     static void create_selector_(const char *id, const char *label);
+    static void create_simple_meter_(const char *id);
     static void create_spin_value_(const char *id, const char *label);
     static void create_switch_no_caption_(const char *sw_type,const char * id);
+    static void create_feedback_switch_(const char *sw_type,const char * id);
     static void create_switch_(const char *sw_type,const char * id, const char *label);
     static void create_wheel_(const char * id, const char *label);
     static void create_port_display_(const char *id, const char *label);
@@ -288,7 +295,7 @@ void CmdConnection::unlisten(const Glib::ustring& tp) {
 	cerr << "unknown listen token: " << tp << endl;
 	return;
     }
-    for (int i = start; i < end; ++i) {
+    for (int i = start; i <= end; i++) {
 	activate(i, false);
     }
 }
@@ -1332,12 +1339,15 @@ UiBuilderVirt::UiBuilderVirt(gx_system::JsonWriter *jw_, const gx_system::Cmdlin
     load_glade = load_glade_;
     load_glade_file = load_glade_file_;
     create_master_slider = create_master_slider_;
+    create_h_slider = create_h_slider_;
     create_small_rackknob = create_small_rackknob_;
     create_small_rackknobr = create_small_rackknobr_;
+    create_simple_meter = create_simple_meter_;
     create_spin_value = create_spin_value_;
     create_switch = create_switch_;
     create_wheel = create_wheel_;
     create_switch_no_caption = create_switch_no_caption_;
+    create_feedback_switch = create_feedback_switch_;
     create_selector = create_selector_;
     create_selector_no_caption = create_selector_no_caption_;
     create_port_display = create_port_display_;
@@ -1449,6 +1459,14 @@ void UiBuilderVirt::create_small_rackknobr_(const char *id, const char *label) {
     jw->end_array();
 }
 
+void UiBuilderVirt::create_h_slider_(const char *id, const char *label) {
+    jw->begin_array();
+    jw->write("create_h_slider");
+    jw->write(id);
+    jw->write(label);
+    jw->end_array();
+}
+
 void UiBuilderVirt::create_master_slider_(const char *id, const char *label) {
     jw->begin_array();
     jw->write("create_master_slider");
@@ -1472,6 +1490,13 @@ void UiBuilderVirt::create_selector_(const char *id, const char *label) {
     jw->end_array();
 }
 
+void UiBuilderVirt::create_simple_meter_(const char *id) {
+    jw->begin_array();
+    jw->write("create_simple_meter");
+    jw->write(id);
+    jw->end_array();
+}
+
 void UiBuilderVirt::create_spin_value_(const char *id, const char *label) {
     jw->begin_array();
     jw->write("create_spin_value");
@@ -1488,6 +1513,14 @@ void UiBuilderVirt::create_switch_no_caption_(const char *sw_type, const char *
     jw->end_array();
 }
 
+void UiBuilderVirt::create_feedback_switch_(const char *sw_type, const char * id) {
+    jw->begin_array();
+    jw->write("create_feedback_switch");
+    jw->write(sw_type);
+    jw->write(id);
+    jw->end_array();
+}
+
 void UiBuilderVirt::create_switch_(const char *sw_type, const char * id, const char *label) {
     jw->begin_array();
     jw->write("create_switch");
@@ -1557,7 +1590,8 @@ void UiBuilderVirt::load_glade_file_(const char *fname) {
  */
 
 GxService::GxService(gx_preset::GxSettings& settings_, gx_jack::GxJack& jack_,
-		     TunerSwitcher& tunerswitcher_, sigc::slot<void> quit_mainloop_, int *port)
+		     TunerSwitcher& tunerswitcher_, sigc::slot<void> quit_mainloop_,
+		     const Glib::ustring& host, int *port)
     : Gio::SocketService(),
       settings(settings_),
       jack(jack_),
@@ -1575,6 +1609,9 @@ GxService::GxService(gx_preset::GxSettings& settings_, gx_jack::GxJack& jack_,
     } else {
 	add_inet_port(*port);
     }
+    if (host.compare(0, 3, "BT:") == 0) {
+	create_bluetooth_sockets(host.substr(3));
+    }
     settings.signal_selection_changed().connect(
 	sigc::mem_fun(*this, &GxService::preset_changed));
     jack.get_engine().signal_state_change().connect(
@@ -1621,6 +1658,48 @@ GxService::~GxService() {
     }
 }
 
+#if HAVE_BLUEZ
+static Glib::RefPtr<Gio::Socket> create_one_bluetooth_socket(
+    const Glib::ustring& device, int channel) {
+    sockaddr_rc loc_addr = { 0 };
+    int s = socket(AF_BLUETOOTH, SOCK_STREAM, BTPROTO_RFCOMM);
+    loc_addr.rc_family = AF_BLUETOOTH;
+    // bind socket to the first available local bluetooth adapter
+    bdaddr_t bdaddr = {{0, 0, 0, 0, 0, 0}}; //*BDADDR_ANY;
+    loc_addr.rc_bdaddr = bdaddr;
+    loc_addr.rc_channel = (uint8_t)channel;
+    bind(s, (struct sockaddr *)&loc_addr, sizeof(loc_addr));
+    listen(s, 1);
+    return Gio::Socket::create_from_fd(s);
+}
+
+void GxService::create_bluetooth_sockets(const Glib::ustring& host) {
+    int channels = 1;
+    if (host.size() > 3) {
+	channels = host[3] - '0';
+	if (channels < 1) {
+	    channels = 1;
+	} else if (channels > 9) {
+	    channels = 9;
+	}
+	}
+    for (int i = 1; i <= channels; i++) {
+	add_socket(create_one_bluetooth_socket(host, i));
+    }
+    gx_print_info(
+	_("server"),
+	Glib::ustring::compose(
+	    _("listening on bluetooth socket (%1 channel)"),
+	    channels));
+}
+#else // !HAVE_BLUEZ
+void GxService::create_bluetooth_sockets(const Glib::ustring& host) {
+    gx_print_fatal(
+	_("server"),
+	_("Bluetooth not available; rebuild Guitarix with Bluetooth support"));
+}
+#endif // HAVE_BLUEZ
+
 void GxService::ladspaloader_write_changes(gx_system::JsonWriter& jw, std::vector<ChangedPlugin>& changed_plugins) {
     serialize_parameter_change(jw);
     // updated plugins
