@@ -1324,7 +1324,7 @@ void MainWindow::on_show_midi_out() {
 	midi_out_box->set_visible(true);
     } else {
 	midi_out_box->set_visible(false);
-	engine.midiaudiobuffer.plugin.on_off = false;
+	machine.pluginlist_lookup_plugin("midi_out")->set_on_off(false);
     }
 #endif
 }
@@ -2356,14 +2356,21 @@ void MainWindow::hide_extended_settings() {
     }
 }
 
+//bool MainWindow::ui_sleep() {
+//    usleep(1900);
+    //cout<<"timeout"<<endl;
+//    return true;
+//}
+
 void MainWindow::run() {
     int port = options.get_rpcport();
     if (machine.get_jack() && port != RPCPORT_DEFAULT && port != RPCPORT_NONE) {
-	machine.start_socket(sigc::ptr_fun(Gtk::Main::quit), port);
+	machine.start_socket(sigc::ptr_fun(Gtk::Main::quit), options.get_rpcaddress(), port);
 	window->show();
 	Gtk::Main::run();
     } else {
 	window->show();
+   // Glib::signal_timeout().connect (mem_fun (*this, &MainWindow::ui_sleep), 2);
 	Gtk::Main::run();
     }
 }
