@@ -295,6 +295,48 @@ void StackBoxBuilder::set_next_flags(int flags) {
     next_flags = flags;
 }
 
+bool StackBoxBuilder::set_simple(Gxw::FastMeter *fastmeter,const std::string id) {
+    if (machine.get_parameter_value<bool>(id.substr(0,id.find_last_of(".")+1)+"on_off"))
+    fastmeter->set_by_power(machine.get_parameter_value<float>(id));
+    else
+    fastmeter->set_by_power(0.0001);
+    return true;
+}
+
+void StackBoxBuilder::create_simple_meter(const std::string& id) {
+    Gxw::FastMeter *fastmeter = new Gxw::FastMeter();
+    fastmeter->set_hold_count(5);
+    fastmeter->set_property("dimen",5);
+    Glib::signal_timeout().connect(sigc::bind<Gxw::FastMeter*>(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_simple),id), fastmeter), 60);
+    fastmeter->set_by_power(0.0001);
+    GxPaintBox *box =  new GxPaintBox(pb_amp_expose);
+    box->set_border_width(2);
+    box->pack_start(*Gtk::manage(static_cast<Gtk::Widget*>(fastmeter)),Gtk::PACK_SHRINK);
+    box->show_all();
+    fBox.box_pack_start(manage(box),false);
+}
+
+bool StackBoxBuilder::set_engine_value(const std::string id) {
+    if (machine.get_parameter_value<bool>(id.substr(0,id.find_last_of(".")+1)+"on_off"))
+      machine.signal_parameter_value<float>(id)(machine.get_parameter_value<float>(id));
+    return true;
+}
+
+void StackBoxBuilder::create_port_display(const std::string& id, const char *label) {
+    CpBaseCaption *w = new UiReglerWithCaption<Gxw::PortDisplay>(machine, id);
+    Glib::signal_timeout().connect(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_engine_value),id), 60);
+	w->set_rack_label(label);
+	addwidget(w);
+}
+
+void StackBoxBuilder::create_feedback_switch(const char *sw_type, const std::string& id) {
+	addwidget(UiSwitch::create(machine, sw_type, id));
+    Glib::signal_timeout().connect(sigc::bind<const std::string>(
+      sigc::mem_fun(*this, &StackBoxBuilder::set_engine_value),id), 60);
+}
+
 void StackBoxBuilder::create_selector(const std::string& id, const char *widget_name) {
     gx_engine::Parameter& p = machine.get_parameter(id);
     Gxw::Selector *s;
@@ -404,22 +446,25 @@ void StackBoxBuilder::openVerticalBox1(const char* label) {
 }
 
 void StackBoxBuilder::openVerticalBox2(const char* label) {
-    GxVBox * box =  new GxVBox();
-    box->set_homogeneous(false);
-    box->set_spacing(0);
+    Gtk::VPaned * box =  new Gtk::VPaned();
     box->set_border_width(0);
-
+    GxHBox * pbox =  new GxHBox();
     if (!fBox.top_is_notebook() && label && label[0]) {
-        box->m_label.set_text(label);
-        box->m_label.set_name("rack_label");
-        box->pack_start(box->m_label, false, false, 0 );
-        fBox.box_pack_start(manage(box));
-        box->show();
-        box->m_label.show();
-        fBox.push(box);
-    } else {
-        fBox.push(fBox.add(manage(box), label));
+        pbox->m_label.set_text(label);
+        pbox->m_label.set_name("rack_label");
+        pbox->pack_start(pbox->m_label, false, false, 0 );
     }
+    pbox->set_border_width(0);
+    box->pack1(*Gtk::manage(static_cast<Gtk::Widget*>(pbox)),true,true);
+    GxHBox * hbox =  new GxHBox();
+    hbox->set_homogeneous(false);
+    hbox->set_spacing(0);
+    hbox->set_border_width(0);
+    box->pack2(*Gtk::manage(static_cast<Gtk::Widget*>(hbox)),true,true);
+    box->set_position(200);
+    fBox.box_pack_start(manage(box), false, false, 0);
+    box->show_all();
+    fBox.push(hbox);
 }
 
 void StackBoxBuilder::openFlipLabelBox(const char* label) {
@@ -654,7 +699,7 @@ void StackBoxBuilder::openTabBox(const char* label) {
 }
 
 void StackBoxBuilder::openpaintampBox(const char* label) {
-    GxPaintBox *box =  new GxPaintBox(pb_RackBox_expose);
+    GxPaintBox *box =  new GxPaintBox("rectangle_skin_color_expose");
     box->m_hbox.set_border_width(4);
     box->set_name(label);
     box->set_tooltip_text(label);
