@@ -52,6 +52,7 @@ struct PluginDef;
 #define sw_button     "button"
 #define sw_pbutton    "pbutton"
 #define sw_rbutton    "rbutton"
+#define sw_prbutton    "prbutton"
 
 #define UI_FORM_STACK 0x01
 #define UI_FORM_GLADE 0x02
@@ -78,13 +79,16 @@ struct UiBuilder {
     // functions by the prefix create_ so please stick to this
     // prefix or change the checker
     void (*create_master_slider)(const char *id, const char *label);
+    void (*create_h_slider)(const char *id, const char *label);
     void (*create_small_rackknob)(const char *id, const char *label);
     void (*create_selector_no_caption)(const char *id);
     void (*create_switch_no_caption)(const char *sw_type,const char * id);
+    void (*create_feedback_switch)(const char *sw_type,const char * id);
     void (*create_spin_value)(const char * id, const char *label);
     void (*create_port_display)(const char * id, const char *label);
     void (*create_switch)(const char *sw_type,const char * id, const char *label);
     void (*create_selector)(const char *id, const char *label);
+    void (*create_simple_meter)(const char *id);
     void (*create_small_rackknobr)(const char *id, const char *label);
     void (*create_wheel)(const char *id, const char *label);
     void (*create_simple_spin_value)(const char *id);
@@ -115,6 +119,8 @@ struct ParamReg {
     void (*registerBoolVar)(const char* id, const char* name, const char* tp,
 			    const char* tooltip, bool* var, bool val);
     void (*registerNonMidiVar)(const char * id, bool*var, bool preset, bool nosave);
+    void (*registerNonMidiFloatVar)(const char * id, float *var, bool preset, bool nosave,
+              float val, float low, float up, float step);
     void (*registerEnumVar)(const char *id, const char* name, const char* tp,
 			    const char* tooltip, const value_pair* values, float *var, float val,
 			    float low, float up, float step);
