@@ -1007,8 +1007,13 @@ void MonoEngine::load_static_plugins() {
     pl.add(&cabinet.plugin,                       PLUGIN_POS_RACK, PGN_GUI);
     pl.add(&preamp.plugin,                        PLUGIN_POS_RACK, PGN_GUI);
     pl.add(pluginlib::abgate::plugin(),           PLUGIN_POS_RACK);
+    pl.add(pluginlib::dubbe::plugin(),           PLUGIN_POS_RACK);
     pl.add(pluginlib::vibe::plugin_mono(),        PLUGIN_POS_RACK);
     pl.add(pluginlib::mbc::plugin(),              PLUGIN_POS_RACK);
+    pl.add(pluginlib::mbd::plugin(),              PLUGIN_POS_RACK);
+    pl.add(pluginlib::mbe::plugin(),              PLUGIN_POS_RACK);
+    pl.add(pluginlib::mbdel::plugin(),              PLUGIN_POS_RACK);
+    pl.add(pluginlib::mbchor::plugin(),              PLUGIN_POS_RACK);
 }
 
 
